pub enum Priority {
Exceptional = 0,
Immediate = 1,
Fast = 2,
High = 3,
Nominal = 4,
Low = 5,
Slow = 6,
Optional = 7,
}Expand description
The priority level of a transmission
Variants
Exceptional = 0
Exceptional is the highest priority level and should only be sent when a total system failure has occurred.
Immediate = 1
Immediate is a high priority message.
Fast = 2
Fast is high priority messages but have looser latency requirements than Immediate messages.
High = 3
High priority messages are more important than Nominal messages but have looser latency requirements than Fast messages.
Nominal = 4
This is what all messages should use by default. Specifically the heartbeat messages should use this priority.
Low = 5
Low priority messages are expected to be sent on a bus under all conditions but cannot prevent the delivery of nominal messages.
Slow = 6
Slow messages are low priority messages that have no time sensitivity at all.
Optional = 7
These messages might never be sent (theoretically) for some possible system states.